fnss.topologies.topology.Topology.add_cycle — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »

# fnss.topologies.topology.Topology.add_cycle

`Topology.` `add_cycle`(nodes, **attr)

  Add a cycle.

  Parameters: | nodes: iterable container : A container of nodes. A cycle will be constructed from the nodes (in order) and added to the graph. attr : keyword arguments, optional (default= no attributes) Attributes to add to every edge in cycle.

  See also

  `add_path`, `add_star`

  Examples

      >>> G=nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_cycle([0,1,2,3])
      >>> G.add_cycle([10,11,12],weight=7)

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »